@@ -257,7 +257,8 @@ def chunkify(files):
       mapped_file = create_mapped_file(filemap['v'], f)
       mapped_file['t'] = 'l'
       mapped_file['v'] = os.readlink(f)
-      mapped_file['p'] = os.stat(f)[ST_MODE]
+      # Symlink does not have its own permissions, permissions of target
+      # are used instead
       continue
     if os.path.isdir(f):
       raise Exception(f'Transmitting directories not supported {f}')
